summaryrefslogtreecommitdiffstats
path: root/lib/private/user.php
diff options
context:
space:
mode:
authorArthur Schiwon <blizzz@owncloud.com>2014-10-22 13:36:57 +0200
committerArthur Schiwon <blizzz@owncloud.com>2014-10-22 13:36:57 +0200
commit993376fb6f62772554e0f35b04f52468021a6cab (patch)
tree64094f181ab367a353a4a546a80ef1b41d9403ea /lib/private/user.php
parente0342db47cc95a1032086a82650d2bdc7814ae57 (diff)
downloadnextcloud-server-993376fb6f62772554e0f35b04f52468021a6cab.tar.gz
nextcloud-server-993376fb6f62772554e0f35b04f52468021a6cab.zip
better variable name
Diffstat (limited to 'lib/private/user.php')
-rw-r--r--lib/private/user.php7
1 files changed, 4 insertions, 3 deletions
diff --git a/lib/private/user.php b/lib/private/user.php
index e02a0aaa1fc..3c23c19b015 100644
--- a/lib/private/user.php
+++ b/lib/private/user.php
@@ -224,16 +224,17 @@ class OC_User {
/**
* Try to login a user
* @param string $uid The username of the user to log in
* @param string $password The password of the user
* @return boolean|null
*
* Log in a user and regenerate a new session - if the password is ok
*/
- public static function login($uid, $password) {
+ public static function login($loginname, $password) {
session_regenerate_id(true);
- $result = self::getUserSession()->login($uid, $password);
+ $result = self::getUserSession()->login($loginname, $password);
if ($result) {
+ //we need to pass the user name, which may differ from login name
OC_Util::setupFS(self::getUserSession()->getUser()->getUID());
}
return $result;
@@ -224,16 +224,17 @@ class OC_User {
/**
* Try to login a user
- * @param string $uid The username of the user to log in
+ * @param string $loginname The login name of the user to log in
* @param string $password The password of the user
* @return boolean|null